'use strict';

var chunkXQNDC64Y_cjs = require('./chunk-XQNDC64Y.cjs');
var pluginOas = require('@kubb/plugin-oas');
var hooks = require('@kubb/plugin-oas/hooks');
var pluginTs = require('@kubb/plugin-ts');
var pluginZod = require('@kubb/plugin-zod');
var react = require('@kubb/react');
var remeda = require('remeda');
var jsxRuntime = require('@kubb/react/jsx-runtime');

var queryGenerator = pluginOas.createReactGenerator({
  name: "svelte-query",
  Operation({ options, operation }) {
    const {
      plugin: {
        options: { output }
      }
    } = react.useApp();
    const { getSchemas, getName, getFile } = hooks.useOperationManager();
    const isQuery = typeof options.query === "boolean" ? true : options.query?.methods.some((method) => operation.method === method);
    const isMutation = remeda.difference(["post", "put", "delete", "patch"], options.query ? options.query.methods : []).some((method) => operation.method === method);
    const importPath = options.query ? options.query.importPath : "@tanstack/solid-query";
    const query = {
      name: getName(operation, { type: "function", prefix: "create" }),
      typeName: getName(operation, { type: "type" }),
      file: getFile(operation, { prefix: "create" })
    };
    const client = {
      name: getName(operation, { type: "function" })
    };
    const queryOptions = {
      name: getName(operation, { type: "function", suffix: "QueryOptions" })
    };
    const queryKey = {
      name: getName(operation, { type: "const", suffix: "QueryKey" }),
      typeName: getName(operation, { type: "type", suffix: "QueryKey" })
    };
    const type = {
      file: getFile(operation, { pluginKey: [pluginTs.pluginTsName] }),
      //todo remove type?
      schemas: getSchemas(operation, { pluginKey: [pluginTs.pluginTsName], type: "type" })
    };
    const zod = {
      file: getFile(operation, { pluginKey: [pluginZod.pluginZodName] }),
      schemas: getSchemas(operation, { pluginKey: [pluginZod.pluginZodName], type: "function" })
    };
    if (!isQuery || isMutation) {
      return null;
    }
    return /* @__PURE__ */ jsxRuntime.jsxs(react.File, { baseName: query.file.baseName, path: query.file.path, meta: query.file.meta, banner: output?.banner, footer: output?.footer, children: [
      options.parser === "zod" && /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: [zod.schemas.response.name], root: query.file.path, path: zod.file.path }),
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: "client", path: options.client.importPath }),
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["RequestConfig"], path: options.client.importPath, isTypeOnly: true }),
      options.client.dataReturnType === "full" && /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["ResponseConfig"], path: options.client.importPath, isTypeOnly: true }),
      /* @__PURE__ */ jsxRuntime.jsx(
        react.File.Import,
        {
          name: [
            type.schemas.request?.name,
            type.schemas.response.name,
            type.schemas.pathParams?.name,
            type.schemas.queryParams?.name,
            type.schemas.headerParams?.name,
            ...type.schemas.statusCodes?.map((item) => item.name) || []
          ].filter(Boolean),
          root: query.file.path,
          path: type.file.path,
          isTypeOnly: true
        }
      ),
      /* @__PURE__ */ jsxRuntime.jsx(
        chunkXQNDC64Y_cjs.QueryKey,
        {
          name: queryKey.name,
          typeName: queryKey.typeName,
          operation,
          paramsCasing: options.paramsCasing,
          pathParamsType: options.pathParamsType,
          typeSchemas: type.schemas,
          transformer: options.queryKey
        }
      ),
      /* @__PURE__ */ jsxRuntime.jsx(
        chunkXQNDC64Y_cjs.Client,
        {
          name: client.name,
          isExportable: false,
          isIndexable: false,
          baseURL: options.client.baseURL,
          operation,
          typeSchemas: type.schemas,
          zodSchemas: zod.schemas,
          dataReturnType: options.client.dataReturnType,
          paramsCasing: options.paramsCasing,
          paramsType: options.paramsType,
          pathParamsType: options.pathParamsType,
          parser: options.parser
        }
      ),
      /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["queryOptions"], path: importPath }),
      /* @__PURE__ */ jsxRuntime.jsx(
        chunkXQNDC64Y_cjs.QueryOptions,
        {
          name: queryOptions.name,
          clientName: client.name,
          queryKeyName: queryKey.name,
          typeSchemas: type.schemas,
          paramsCasing: options.paramsCasing,
          paramsType: options.paramsType,
          pathParamsType: options.pathParamsType,
          dataReturnType: options.client.dataReturnType
        }
      ),
      options.query && /* @__PURE__ */ jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [
        /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["createQuery"], path: importPath }),
        /* @__PURE__ */ jsxRuntime.jsx(react.File.Import, { name: ["QueryKey", "CreateBaseQueryOptions", "CreateQueryResult"], path: importPath, isTypeOnly: true }),
        /* @__PURE__ */ jsxRuntime.jsx(
          chunkXQNDC64Y_cjs.Query,
          {
            name: query.name,
            queryOptionsName: queryOptions.name,
            typeSchemas: type.schemas,
            paramsType: options.paramsType,
            pathParamsType: options.pathParamsType,
            operation,
            paramsCasing: options.paramsCasing,
            dataReturnType: options.client.dataReturnType,
            queryKeyName: queryKey.name,
            queryKeyTypeName: queryKey.typeName
          }
        )
      ] })
    ] });
  }
});

exports.queryGenerator = queryGenerator;
//# sourceMappingURL=chunk-JOFIK6QT.cjs.map
//# sourceMappingURL=chunk-JOFIK6QT.cjs.map